pub fn registry() -> &'static AlgorithmRegistryExpand description
Get the global algorithm registry Requires alloc feature (registry uses HashMap/BTreeMap internally)
pub fn registry() -> &'static AlgorithmRegistryGet the global algorithm registry Requires alloc feature (registry uses HashMap/BTreeMap internally)